﻿using System;
using System.Drawing;
using System.Linq;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using Syncfusion.Pdf.Grid;

namespace PdfSample
{
    class Program
    {
        static void Main(string[] args)
        {
            //Creates a new PDF document.
            PdfDocument pdfDocument = new PdfDocument();
            float marginSize = 15;
            pdfDocument.PageSettings.Margins.All = marginSize;
            PdfPage pdfPage = pdfDocument.Pages.Add();


            //Draw something that came before the grid
            PdfStringFormat format = new PdfStringFormat()
                                     {
                                         Alignment = PdfTextAlignment.Justify,
                                         LineAlignment = PdfVerticalAlignment.Top,
                                         ParagraphIndent = 15f
                                     };
            PdfStandardFont textFont = new PdfStandardFont(PdfFontFamily.TimesRoman, 8);
            PdfTextElement element = new PdfTextElement(LongText, textFont)
                                     {
                                         Brush = new PdfSolidBrush(Color.Black),
                                         StringFormat = format
                                     };
            PdfLayoutFormat layoutFormat = new PdfLayoutFormat()
                                           {
                                               Break = PdfLayoutBreakType.FitPage,
                                               Layout = PdfLayoutType.Paginate
                                           };
            RectangleF bounds = new RectangleF(0, 25, pdfPage.GetClientSize().Width, pdfPage.GetClientSize().Height);
            PdfTextLayoutResult pdfTextLayoutResult = element.Draw(pdfPage, bounds, layoutFormat);

            //Draw the grid title
            PdfFont titleFont = new PdfStandardFont(PdfFontFamily.Helvetica, 14);
            PdfTextElement gridTitle = new PdfTextElement("Employee Payroll for the month of August 20xx", titleFont);
            PdfLayoutResult titleResult = gridTitle.Draw(pdfTextLayoutResult.Page, new PointF(0, pdfTextLayoutResult.Bounds.Bottom + 20));

            //Draw the grid
            PdfGrid pdfGrid = new PdfGrid();
            pdfGrid.RepeatHeader = true;
            //Adds three columns.
            pdfGrid.Columns.Add(8);
            //Adds header.
            pdfGrid.Headers.Add(1);
            PdfGridRow pdfGridHeader = pdfGrid.Headers[0];
            pdfGridHeader.Cells[0].Value = "Employee ID";
            pdfGridHeader.Cells[1].Value = "Employee Name";
            pdfGridHeader.Cells[2].Value = "Annual Salary";
            pdfGridHeader.Cells[3].Value = "Salary for Current Month";
            pdfGridHeader.Cells[4].Value = "Salary paid Year to Date";
            pdfGridHeader.Cells[5].Value = "Federal Income Tax Withheld Year to Date";
            pdfGridHeader.Cells[6].Value = "State Income Tax Withheld Year to Date";
            pdfGridHeader.Cells[7].Value = "Medicaid Withheld Year to Date";
            pdfGridHeader.Style = new PdfGridRowStyle()
                                  {
                                      Font = new PdfStandardFont(PdfFontFamily.Helvetica, 8f, PdfFontStyle.Bold)
                                  };
            //Adds rows.
            for (var i = 0; i < 60; ++i)
            {
                PdfGridRow pdfGridRow = pdfGrid.Rows.Add();
                pdfGridRow.Cells[0].Value = "E01";
                pdfGridRow.Cells[1].Value = "Jonathon Fredrick Richardson, III";
                pdfGridRow.Cells[2].Value = "$60,000";
                pdfGridRow.Cells[3].Value = "$5,000";
                pdfGridRow.Cells[4].Value = "$40,000";
                pdfGridRow.Cells[5].Value = "$3,439";
                pdfGridRow.Cells[6].Value = "$1,821";
                pdfGridRow.Cells[7].Value = "$1,003";
            }
            //Draws the PdfGrid.
            PdfGridLayoutResult gridResult = pdfGrid.Draw(titleResult.Page, new PointF(0, titleResult.Bounds.Bottom + 10));

            //Saves the document.
            pdfDocument.Save(@"c:\temp\Output.pdf");
            pdfDocument.Close(true);
        }

        public static string LongText = @"CHAPTER I

""Well, Prince, so Genoa and Lucca are now just family estates of the Buonapartes. But I warn you, if you don't tell me that this means war, if you still try to defend the infamies and horrors perpetrated by that Antichrist—I really believe he is Antichrist—I will have nothing more to do with you and you are no longer my friend, no longer my 'faithful slave,' as you call yourself! But how do you do? I see I have frightened you—sit down and tell me all the news.""
It was in July, 1805, and the speaker was the well-known Anna Pavlovna Scherer, maid of honor and favorite of the Empress Marya Fedorovna. With these words she greeted Prince Vasili Kuragin, a man of high rank and importance, who was the first to arrive at her reception. Anna Pavlovna had had a cough for some days. She was, as she said, suffering from la grippe; grippe being then a new word in St. Petersburg, used only by the elite.
All her invitations without exception, written in French, and delivered by a scarlet-liveried footman that morning, ran as follows:
""If you have nothing better to do, Count (or Prince), and if the prospect of spending an evening with a poor invalid is not too terrible, I shall be very charmed to see you tonight between 7 and 10—Annette Scherer.""
""Heavens! what a virulent attack!"" replied the prince, not in the least disconcerted by this reception. He had just entered, wearing an embroidered court uniform, knee breeches, and shoes, and had stars on his breast and a serene expression on his flat face. He spoke in that refined French in which our grandfathers not only spoke but thought, and with the gentle, patronizing intonation natural to a man of importance who had grown old in society and at court. He went up to Anna Pavlovna, kissed her hand, presenting to her his bald, scented, and shining head, and complacently seated himself on the sofa.
""First of all, dear friend, tell me how you are. Set your friend's mind at rest,"" said he without altering his tone, beneath the politeness and affected sympathy of which indifference and even irony could be discerned.
""Can one be well while suffering morally? Can one be calm in times like these if one has any feeling?"" said Anna Pavlovna. ""You are staying the whole evening, I hope?""
""And the fete at the English ambassador's? Today is Wednesday. I must put in an appearance there,"" said the prince. ""My daughter is coming for me to take me there.""
""I thought today's fete had been canceled. I confess all these festivities and fireworks are becoming wearisome.""
""If they had known that you wished it, the entertainment would have been put off,"" said the prince, who, like a wound-up clock, by force of habit said things he did not even wish to be believed.
""Don't tease! Well, and what has been decided about Novosiltsev's dispatch? You know everything.""
""What can one say about it?"" replied the prince in a cold, listless tone. ""What has been decided? They have decided that Buonaparte has burnt his boats, and I believe that we are ready to burn ours.""
Prince Vasili always spoke languidly, like an actor repeating a stale part. Anna Pavlovna Scherer on the contrary, despite her forty years, overflowed with animation and impulsiveness. To be an enthusiast had become her social vocation and, sometimes even when she did not feel like it, she became enthusiastic in order not to disappoint the expectations of those who knew her. The subdued smile which, though it did not suit her faded features, always played round her lips expressed, as in a spoiled child, a continual consciousness of her charming defect, which she neither wished, nor could, nor considered it necessary, to correct.
In the midst of a conversation on political matters Anna Pavlovna burst out:
""Oh, don't speak to me of Austria. Perhaps I don't understand things, but Austria never has wished, and does not wish, for war. She is betraying us! Russia alone must save Europe. Our gracious sovereign recognizes his high vocation and will be true to it. That is the one thing I have faith in! Our good and wonderful sovereign has to perform the noblest role on earth, and he is so virtuous and noble that God will not forsake him. He will fulfill his vocation and crush the hydra of revolution, which has become more terrible than ever in the person of this murderer and villain! We alone must avenge the blood of the just one.... Whom, I ask you, can we rely on?... England with her commercial spirit will not and cannot understand the Emperor Alexander's loftiness of soul. She has refused to evacuate Malta. She wanted to find, and still seeks, some secret motive in our actions. What answer did Novosiltsev get? None. The English have not understood and cannot understand the self-abnegation of our Emperor who wants nothing for himself, but only desires the good of mankind. And what have they promised? Nothing! And what little they have promised they will not perform! Prussia has always declared that Buonaparte is invincible, and that all Europe is powerless before him.... And I don't believe a word that Hardenburg says, or Haugwitz either. This famous Prussian neutrality is just a trap. I have faith only in God and the lofty destiny of our adored monarch. He will save Europe!""
She suddenly paused, smiling at her own impetuosity.
""I think,"" said the prince with a smile, ""that if you had been sent instead of our dear Wintzingerode you would have captured the King of Prussia's consent by assault. You are so eloquent. Will you give me a cup of tea?""
""In a moment. A propos,"" she added, becoming calm again, ""I am expecting two very interesting men tonight, le Vicomte de Mortemart, who is connected with the Montmorencys through the Rohans, one of the best French families. He is one of the genuine emigres, the good ones. And also the Abbe Morio. Do you know that profound thinker? He has been received by the Emperor. Had you heard?""
""I shall be delighted to meet them,"" said the prince. ""But tell me,"" he added with studied carelessness as if it had only just occurred to him, though the question he was about to ask was the chief motive of his visit, ""is it true that the Dowager Empress wants Baron Funke to be appointed first secretary at Vienna? The baron by all accounts is a poor creature.""
Prince Vasili wished to obtain this post for his son, but others were trying through the Dowager Empress Marya Fedorovna to secure it for the baron.
Anna Pavlovna almost closed her eyes to indicate that neither she nor anyone else had a right to criticize what the Empress desired or was pleased with.
""Baron Funke has been recommended to the Dowager Empress by her sister,"" was all she said, in a dry and mournful tone.
As she named the Empress, Anna Pavlovna's face suddenly assumed an expression of profound and sincere devotion and respect mingled with sadness, and this occurred every time she mentioned her illustrious patroness. She added that Her Majesty had deigned to show Baron Funke beaucoup d'estime, and again her face clouded over with sadness.
The prince was silent and looked indifferent. But, with the womanly and courtierlike quickness and tact habitual to her, Anna Pavlovna wished both to rebuke him (for daring to speak as he had done of a man recommended to the Empress) and at the same time to console him, so she said:
""Now about your family. Do you know that since your daughter came out everyone has been enraptured by her? They say she is amazingly beautiful.""
The prince bowed to signify his respect and gratitude.
""I often think,"" she continued after a short pause, drawing nearer to the prince and smiling amiably at him as if to show that political and social topics were ended and the time had come for intimate conversation—""I often think how unfairly sometimes the joys of life are distributed. Why has fate given you two such splendid children? I don't speak of Anatole, your youngest. I don't like him,"" she added in a tone admitting of no rejoinder and raising her eyebrows. ""Two such charming children. And really you appreciate them less than anyone, and so you don't deserve to have them.""
And she smiled her ecstatic smile.
""I can't help it,"" said the prince. ""Lavater would have said I lack the bump of paternity.""
""Don't joke; I mean to have a serious talk with you. Do you know I am dissatisfied with your younger son? Between ourselves"" (and her face assumed its melancholy expression), ""he was mentioned at Her Majesty's and you were pitied....""
The prince answered nothing, but she looked at him significantly, awaiting a reply. He frowned.
""What would you have me do?"" he said at last. ""You know I did all a father could for their education, and they have both turned out fools. Hippolyte is at least a quiet fool, but Anatole is an active one. That is the only difference between them."" He said this smiling in a way more natural and animated than usual, so that the wrinkles round his mouth very clearly revealed something unexpectedly coarse and unpleasant.
""And why are children born to such men as you? If you were not a father there would be nothing I could reproach you with,"" said Anna Pavlovna, looking up pensively.
""I am your faithful slave and to you alone I can confess that my children are the bane of my life. It is the cross I have to bear. That is how I explain it to myself. It can't be helped!""
He said no more, but expressed his resignation to cruel fate by a gesture. Anna Pavlovna meditated.
""Have you never thought of marrying your prodigal son Anatole?"" she asked. ""They say old maids have a mania for matchmaking, and though I don't feel that weakness in myself as yet, I know a little person who is very unhappy with her father. She is a relation of yours, Princess Mary Bolkonskaya.""
Prince Vasili did not reply, though, with the quickness of memory and perception befitting a man of the world, he indicated by a movement of the head that he was considering this information.
";
    }
}
